==> fontconfig-2.13.0-x86_64-1.txz: install/doinst.sh <==
( cd usr/share/fontconfig ; rm -rf conf.avail )
( cd usr/share/fontconfig ; ln -sf /etc/fonts/conf.avail conf.avail )
( cd usr/lib64 ; rm -rf libfontconfig.so.1 )
( cd usr/lib64 ; ln -sf libfontconfig.so.1.11.1 libfontconfig.so.1 )
( cd usr/lib64 ; rm -rf libfontconfig.so )
( cd usr/lib64 ; ln -sf libfontconfig.so.1.11.1 libfontconfig.so )
( cd etc/fonts/conf.d ; rm -rf 45-generic.conf )
( cd etc/fonts/conf.d ; ln -sf /etc/fonts/conf.avail/45-generic.conf 45-generic.conf )
( cd etc/fonts/conf.d ; rm -rf 10-scale-bitmap-fonts.conf )
( cd etc/fonts/conf.d ; ln -sf /etc/fonts/conf.avail/10-scale-bitmap-fonts.conf 10-scale-bitmap-fonts.conf )
( cd etc/fonts/conf.d ; rm -rf 65-fonts-persian.conf )
( cd etc/fonts/conf.d ; ln -sf ../conf.avail/65-fonts-persian.conf 65-fonts-persian.conf )
( cd etc/fonts/conf.d ; rm -rf 69-unifont.conf )
( cd etc/fonts/conf.d ; ln -sf ../conf.avail/69-unifont.conf 69-unifont.conf )
( cd etc/fonts/conf.d ; rm -rf 60-generic.conf )
( cd etc/fonts/conf.d ; ln -sf /etc/fonts/conf.avail/60-generic.conf 60-generic.conf )
( cd etc/fonts/conf.d ; rm -rf 60-latin.conf )
( cd etc/fonts/conf.d ; ln -sf ../conf.avail/60-latin.conf 60-latin.conf )
( cd etc/fonts/conf.d ; rm -rf 65-nonlatin.conf )
( cd etc/fonts/conf.d ; ln -sf ../conf.avail/65-nonlatin.conf 65-nonlatin.conf )
( cd etc/fonts/conf.d ; rm -rf 80-delicious.conf )
( cd etc/fonts/conf.d ; ln -sf ../conf.avail/80-delicious.conf 80-delicious.conf )
( cd etc/fonts/conf.d ; rm -rf 30-metric-aliases.conf )
( cd etc/fonts/conf.d ; ln -sf ../conf.avail/30-metric-aliases.conf 30-metric-aliases.conf )
( cd etc/fonts/conf.d ; rm -rf 20-unhint-small-vera.conf )
( cd etc/fonts/conf.d ; ln -sf ../conf.avail/20-unhint-small-vera.conf 20-unhint-small-vera.conf )
( cd etc/fonts/conf.d ; rm -rf 49-sansserif.conf )
( cd etc/fonts/conf.d ; ln -sf ../conf.avail/49-sansserif.conf 49-sansserif.conf )
( cd etc/fonts/conf.d ; rm -rf 40-nonlatin.conf )
( cd etc/fonts/conf.d ; ln -sf ../conf.avail/40-nonlatin.conf 40-nonlatin.conf )
( cd etc/fonts/conf.d ; rm -rf 90-synthetic.conf )
( cd etc/fonts/conf.d ; ln -sf ../conf.avail/90-synthetic.conf 90-synthetic.conf )
( cd etc/fonts/conf.d ; rm -rf 51-local.conf )
( cd etc/fonts/conf.d ; ln -sf ../conf.avail/51-local.conf 51-local.conf )
( cd etc/fonts/conf.d ; rm -rf 50-user.conf )
( cd etc/fonts/conf.d ; ln -sf ../conf.avail/50-user.conf 50-user.conf )
( cd etc/fonts/conf.d ; rm -rf 45-latin.conf )
( cd etc/fonts/conf.d ; ln -sf ../conf.avail/45-latin.conf 45-latin.conf )

# Update the X font indexes:
if [ -x /usr/bin/fc-cache ]; then
  /usr/bin/fc-cache -f
fi
# else we'll catch it later with setup.fontconfig :-)

==> fontconfig-2.13.1-x86_64-1.txz: install/doinst.sh <==
( cd etc/fonts/conf.d ; rm -rf 10-scale-bitmap-fonts.conf )
( cd etc/fonts/conf.d ; ln -sf /etc/fonts/conf.avail/10-scale-bitmap-fonts.conf 10-scale-bitmap-fonts.conf )
( cd etc/fonts/conf.d ; rm -rf 20-unhint-small-vera.conf )
( cd etc/fonts/conf.d ; ln -sf ../conf.avail/20-unhint-small-vera.conf 20-unhint-small-vera.conf )
( cd etc/fonts/conf.d ; rm -rf 30-metric-aliases.conf )
( cd etc/fonts/conf.d ; ln -sf ../conf.avail/30-metric-aliases.conf 30-metric-aliases.conf )
( cd etc/fonts/conf.d ; rm -rf 40-nonlatin.conf )
( cd etc/fonts/conf.d ; ln -sf ../conf.avail/40-nonlatin.conf 40-nonlatin.conf )
( cd etc/fonts/conf.d ; rm -rf 45-generic.conf )
( cd etc/fonts/conf.d ; ln -sf /etc/fonts/conf.avail/45-generic.conf 45-generic.conf )
( cd etc/fonts/conf.d ; rm -rf 45-latin.conf )
( cd etc/fonts/conf.d ; ln -sf ../conf.avail/45-latin.conf 45-latin.conf )
( cd etc/fonts/conf.d ; rm -rf 49-sansserif.conf )
( cd etc/fonts/conf.d ; ln -sf ../conf.avail/49-sansserif.conf 49-sansserif.conf )
( cd etc/fonts/conf.d ; rm -rf 50-user.conf )
( cd etc/fonts/conf.d ; ln -sf ../conf.avail/50-user.conf 50-user.conf )
( cd etc/fonts/conf.d ; rm -rf 51-local.conf )
( cd etc/fonts/conf.d ; ln -sf ../conf.avail/51-local.conf 51-local.conf )
( cd etc/fonts/conf.d ; rm -rf 60-generic.conf )
( cd etc/fonts/conf.d ; ln -sf /etc/fonts/conf.avail/60-generic.conf 60-generic.conf )
( cd etc/fonts/conf.d ; rm -rf 60-latin.conf )
( cd etc/fonts/conf.d ; ln -sf ../conf.avail/60-latin.conf 60-latin.conf )
( cd etc/fonts/conf.d ; rm -rf 65-fonts-persian.conf )
( cd etc/fonts/conf.d ; ln -sf ../conf.avail/65-fonts-persian.conf 65-fonts-persian.conf )
( cd etc/fonts/conf.d ; rm -rf 65-nonlatin.conf )
( cd etc/fonts/conf.d ; ln -sf ../conf.avail/65-nonlatin.conf 65-nonlatin.conf )
( cd etc/fonts/conf.d ; rm -rf 69-unifont.conf )
( cd etc/fonts/conf.d ; ln -sf ../conf.avail/69-unifont.conf 69-unifont.conf )
( cd etc/fonts/conf.d ; rm -rf 80-delicious.conf )
( cd etc/fonts/conf.d ; ln -sf ../conf.avail/80-delicious.conf 80-delicious.conf )
( cd etc/fonts/conf.d ; rm -rf 90-synthetic.conf )
( cd etc/fonts/conf.d ; ln -sf ../conf.avail/90-synthetic.conf 90-synthetic.conf )
( cd usr/lib64 ; rm -rf libfontconfig.so )
( cd usr/lib64 ; ln -sf libfontconfig.so.1.12.0 libfontconfig.so )
( cd usr/lib64 ; rm -rf libfontconfig.so.1 )
( cd usr/lib64 ; ln -sf libfontconfig.so.1.12.0 libfontconfig.so.1 )
( cd usr/share/fontconfig ; rm -rf conf.avail )
( cd usr/share/fontconfig ; ln -sf /etc/fonts/conf.avail conf.avail )

# Update the X font indexes:
if [ -x /usr/bin/fc-cache ]; then
  /usr/bin/fc-cache -f
fi
# else we'll catch it later with setup.fontconfig :-)
